@@ -39,11 +39,18 @@ TITLE_CHOICES = Choices(
 NEW_WEBSITE = 1
 CUSTOMER_WEBSITE = 2
 NEW_LANDINGPAGE = 3
+EXISTING_STROER_LANDINGPAGE = 3
 LANDING_PAGE_CHOICES = Choices(
     (NEW_WEBSITE, 'new', _('New website')),
     (CUSTOMER_WEBSITE, 'customer', _('Customer website')),
 )
 
+SEO_LANDING_PAGE_CHOICES = Choices(
+    (NEW_WEBSITE, 'new', _('New website')),
+    (CUSTOMER_WEBSITE, 'customer', _('Website from another provider')),
+    (EXISTING_STROER_LANDINGPAGE, 'existing_stroer_lp', _('Existing Stroer Landing Page')),
+)
+
 GOOGLE_ADS_LANDING_PAGE_CHOICES = Choices(
     (NEW_WEBSITE, 'new', _('New website')),
     (NEW_LANDINGPAGE, 'new_lp', _('New landingpage')),
@@ -1261,7 +1268,6 @@ class OrderLineDisplayNativeSerializer(serializers.Serializer):
 
     '''
     where should the native advertisement be linked?
-    required for `native_ad_out` and `native_ad_flow_ad_out` ads types
     '''
     target_url = serializers.URLField(max_length=400, allow_blank=True, required=False)
 
@@ -1342,10 +1348,6 @@ class OrderLineDisplayNativeSerializer(serializers.Serializer):
             NATIVE_AD_TYPES.native_ad_flow_ad_out: [BILLING_TYPES.cpm],
             NATIVE_AD_TYPES.native_ad_flow_ad_prospect: [BILLING_TYPES.cpm],
         }
-        TARGET_URL_REQUIRED_FOR = [
-            NATIVE_AD_TYPES.native_ad_out,
-            NATIVE_AD_TYPES.native_ad_flow_ad_out,
-        ]
 
         required_message = 'This field is required.'
 
@@ -1355,9 +1357,6 @@ class OrderLineDisplayNativeSerializer(serializers.Serializer):
         if billing_type and billing_type not in BILLING_TYPES_MAP[ad_type]:
             errors.append({'billing_type': '"ad_type" and "billing_type" fields not match each other.'})
 
-        if ad_type in TARGET_URL_REQUIRED_FOR and not data.get('target_url'):
-            errors.append({'target_url': required_message})
-
         age_group_from = data.get('age_group_from')
         age_group_to = data.get('age_group_to')
         if not (age_group_from and age_group_to):
@@ -1877,7 +1876,7 @@ class OrderLineSeoSerializer(serializers.Serializer):
     chose which type of target page should be used in the ad? new or existing website
 
     """
-    target_page_type = serializers.ChoiceField(choices=LANDING_PAGE_CHOICES, required=True)
+    target_page_type = serializers.ChoiceField(choices=SEO_LANDING_PAGE_CHOICES, required=True)
 
     """
     url of the target website if CUSTOMER_WEBSITE is chosen in target_page_type
@@ -1935,6 +1934,11 @@ class OrderLineSeoSerializer(serializers.Serializer):
     """
     ticket_id = serializers.CharField(max_length=20, required=False)
 
+    """
+    describes what the customer's expectation regarding the product is.
+    """
+    campaign_goal = serializers.CharField(max_length=1000, allow_blank=True, required=False)
+
 
 class OrderLineLandingpageSerializer(serializers.Serializer):
     """
@@ -2390,6 +2394,16 @@ class OrderLineSerializer(serializers.Serializer):
     """
     is_pre_briefing_necessary = serializers.BooleanField(default=False)
 
+    """
+    salesforce opportunity line item id
+    """
+    salesforce_opportunity_line_item_id = serializers.CharField(
+        min_length=15,
+        max_length=18,
+        allow_blank=True,
+        required=False
+    )
+
 
 class SellerSerializer(serializers.Serializer):
     """
@@ -2490,6 +2504,7 @@ class OrderSerializer(serializers.Serializer):
     multiple seller shares can be attached to a single order but their overall share must be exactly 100%
     """
     sellershares = SellerShareSerializer(many=True, required=True)
+    salesforce_opportunity_id = serializers.CharField(min_length=15, max_length=18, required=True)
 
 
 class Serializer(serializers.Serializer):
@@ -2582,7 +2597,7 @@ class Serializer(serializers.Serializer):
             if orderline['product_type'] in PRODUCT_TYPE_ORDER_ATTRIBUTES_MAPPING:
                 detail_attribute = PRODUCT_TYPE_ORDER_ATTRIBUTES_MAPPING[orderline['product_type']].intersection(
                     orderline.keys()).pop()
-                if orderline[detail_attribute].get('target_page_type') == NEW_WEBSITE:
+                if orderline[detail_attribute].get('target_page_type') in (NEW_WEBSITE, EXISTING_STROER_LANDINGPAGE):
                     needs_website = True
                 if orderline[detail_attribute].get('target_page_type') == NEW_LANDINGPAGE:
                     needs_landingpage = True
